@@ -65,6 +65,26 @@ from typing import List
 from colorama import init  # type: ignore
 from typing_extensions import Final
 
+__all__ = [
+		"CSI",
+		"OSC",
+		"BEL",
+		"code_to_chars",
+		"set_title",
+		"clear_screen",
+		"clear_line",
+		"Colour",
+		"AnsiCodes",
+		"AnsiCursor",
+		"AnsiFore",
+		"AnsiBack",
+		"AnsiStyle",
+		"Fore",
+		"Back",
+		"Style",
+		"Cursor",
+		]
+
 init()
 
 CSI: Final[str] = "\033["
@@ -162,7 +182,6 @@ class AnsiCursor:
 		:type n: int
 
 		:return:
-		:rtype: str
 		"""
 
 		return f"{CSI}{str(n)}A"
@@ -174,7 +193,6 @@ class AnsiCursor:
 		:type n: int
 
 		:return:
-		:rtype: str
 		"""
 
 		return f"{CSI}{str(n)}B"
@@ -186,7 +204,6 @@ class AnsiCursor:
 		:type n: int
 
 		:return:
-		:rtype: str
 		"""
 
 		return f"{CSI}{str(n)}C"
@@ -198,7 +215,6 @@ class AnsiCursor:
 		:type n: int
 
 		:return:
-		:rtype: str
 		"""
 
 		return f"{CSI}{str(n)}D"
@@ -212,7 +228,6 @@ class AnsiCursor:
 		:type y: int
 
 		:return:
-		:rtype: str
 		"""
 
 		return f"{CSI}{str(y)};{str(x)}H"
